@@ -20,7 +20,7 @@ logger = logging.getLogger(__name__)
 
 socket_path = '/run/freedombox/privileged.socket'
 
-thread_storage = None
+thread_storage = threading.local()
 
 
 # An alias for 'str' to mark some strings as sensitive. Sensitive strings are
@@ -88,6 +88,9 @@ def _read_from_server(client_socket: socket.socket) -> bytes:
 
         response += chunk
 
+    if not response:
+        raise ConnectionError('Server returned empty response')
+
     return json.loads(response)
 
 
@@ -170,8 +173,8 @@ def _wait_for_server_response(func, module_name, action_name, args, kwargs,
     module = importlib.import_module(return_value['exception']['module'])
     exception_class = getattr(module, return_value['exception']['name'])
     exception = exception_class(*return_value['exception']['args'])
-    exception.stdout = return_value['exception']['stdout'].encode()
-    exception.stderr = return_value['exception']['stderr'].encode()
+    exception.stdout = return_value['exception'].get('stdout', b'').encode()
+    exception.stderr = return_value['exception'].get('stderr', b'').encode()
 
     def _get_html_message():
         """Return an HTML format error that can be shown in messages."""
@@ -364,7 +367,6 @@ class JSONEncoder(json.JSONEncoder):
 def _setup_thread_storage():
     """Setup collection of stdout/stderr from any process in this thread."""
     global thread_storage
-    thread_storage = threading.local()
     thread_storage.stdout = b''
     thread_storage.stderr = b''
 
@@ -376,14 +378,13 @@ def _clear_thread_storage():
     cleaned up after a thread terminates.
     """
     global thread_storage
-    if thread_storage:
-        thread_storage.stdout = None
-        thread_storage.stderr = None
-        thread_storage = None
+    thread_storage.stdout = None
+    thread_storage.stderr = None
 
 
 def get_return_value_from_exception(exception):
     """Return the value to return from server when an exception is raised."""
+    global thread_storage
     return_value = {
         'result': 'exception',
         'exception': {
@@ -391,14 +392,10 @@ def get_return_value_from_exception(exception):
             'name': type(exception).__name__,
             'args': exception.args,
             'traceback': traceback.format_tb(exception.__traceback__),
-            'stdout': '',
-            'stderr': ''
+            'stdout': getattr(thread_storage, 'stdout', b'').decode(),
+            'stderr': getattr(thread_storage, 'stderr', b'').decode(),
         }
     }
-    if thread_storage:
-        return_value['exception']['stdout'] = thread_storage.stdout.decode()
-        return_value['exception']['stderr'] = thread_storage.stderr.decode()
-
     return return_value
 
 
@@ -431,8 +428,6 @@ def privileged_handle_json_request(
 
     try:
         request = _parse_request()
-        logger.info('Received request for %s..%s(..)', request['module'],
-                    request['action'])
         arguments = {'args': request['args'], 'kwargs': request['kwargs']}
         _setup_thread_storage()
         return_value = _privileged_call(request['module'], request['action'],
@@ -495,6 +490,8 @@ def _privileged_call(module_name, action_name, arguments):
 
     _privileged_assert_valid_arguments(func, arguments)
 
+    _log_action(func, module_name, action_name, arguments['args'],
+                arguments['kwargs'], run_in_background=False)
     try:
         return_values = func(*arguments['args'], **arguments['kwargs'])
         if isinstance(return_values, io.BufferedReader):
@@ -503,6 +500,11 @@ def _privileged_call(module_name, action_name, arguments):
         return_value = {'result': 'success', 'return': return_values}
     except Exception as exception:
         return_value = get_return_value_from_exception(exception)
+        logger.exception(
+            'Error running action: %s..%s(..): %s\nstdout:\n%s\nstderr:\n%s\n',
+            module_name, action_name, exception,
+            return_value['exception']['stdout'],
+            return_value['exception']['stderr'])
 
     return return_value
 
