@@ -4,14 +4,14 @@ Test module for webserver components.
 """
 
 import subprocess
-from unittest.mock import call, patch
+from unittest.mock import Mock, PropertyMock, call, patch
 
 import pytest
 
-from plinth import app
+from plinth import app, kvstore
 from plinth.diagnostic_check import DiagnosticCheck, Result
-from plinth.modules.apache.components import (Uwsgi, Webserver, check_url,
-                                              diagnose_url,
+from plinth.modules.apache.components import (Uwsgi, Webserver, WebserverRoot,
+                                              check_url, diagnose_url,
                                               diagnose_url_on_all)
 
 
@@ -72,13 +72,16 @@ def test_webserver_disable(disable):
 def test_webserver_diagnose(diagnose_url_on_all, diagnose_url):
     """Test running diagnostics."""
 
-    def on_all_side_effect(url, check_certificate, expect_redirects):
+    def on_all_side_effect(url, check_certificate, expect_redirects,
+                           component_id):
         return [
-            DiagnosticCheck('test-all-id', 'test-result-' + url, 'success')
+            DiagnosticCheck('test-all-id', 'test-result-' + url, 'success', {},
+                            component_id)
         ]
 
-    def side_effect(url, check_certificate):
-        return DiagnosticCheck('test-id', 'test-result-' + url, 'success')
+    def side_effect(url, check_certificate, component_id):
+        return DiagnosticCheck('test-id', 'test-result-' + url, 'success', {},
+                               component_id)
 
     diagnose_url_on_all.side_effect = on_all_side_effect
     diagnose_url.side_effect = side_effect
@@ -86,19 +89,26 @@ def test_webserver_diagnose(diagnose_url_on_all, diagnose_url):
                            urls=['{host}url1', 'url2'], expect_redirects=True)
     results = webserver1.diagnose()
     assert results == [
-        DiagnosticCheck('test-all-id', 'test-result-{host}url1', 'success'),
-        DiagnosticCheck('test-id', 'test-result-url2', 'success')
+        DiagnosticCheck('test-all-id', 'test-result-{host}url1', 'success', {},
+                        'test-webserver'),
+        DiagnosticCheck('test-id', 'test-result-url2', 'success', {},
+                        'test-webserver')
     ]
-    diagnose_url_on_all.assert_has_calls(
-        [call('{host}url1', check_certificate=False, expect_redirects=True)])
-    diagnose_url.assert_has_calls([call('url2', check_certificate=False)])
+    diagnose_url_on_all.assert_has_calls([
+        call('{host}url1', check_certificate=False, expect_redirects=True,
+             component_id='test-webserver')
+    ])
+    diagnose_url.assert_has_calls(
+        [call('url2', check_certificate=False, component_id='test-webserver')])
 
     diagnose_url_on_all.reset_mock()
     webserver2 = Webserver('test-webserver', 'test-config',
                            urls=['{host}url1', 'url2'], expect_redirects=False)
     results = webserver2.diagnose()
-    diagnose_url_on_all.assert_has_calls(
-        [call('{host}url1', check_certificate=False, expect_redirects=False)])
+    diagnose_url_on_all.assert_has_calls([
+        call('{host}url1', check_certificate=False, expect_redirects=False,
+             component_id='test-webserver')
+    ])
 
 
 @patch('plinth.privileged.service.restart')
@@ -154,6 +164,168 @@ def test_webserver_setup(service_reload, service_restart):
     service_reload.assert_not_called()
 
 
+def test_webserver_root_init():
+    """Test that webserver root component can be initialized."""
+    with pytest.raises(ValueError):
+        WebserverRoot(None, None)
+
+    webserver = WebserverRoot('test-webserverroot', 'test-config',
+                              expect_redirects=True, last_updated_version=10)
+    assert webserver.component_id == 'test-webserverroot'
+    assert webserver.web_name == 'test-config'
+    assert webserver.expect_redirects
+    assert webserver.last_updated_version == 10
+
+    webserver = WebserverRoot('test-webserverroot', None)
+    assert not webserver.expect_redirects
+    assert webserver.last_updated_version == 0
+
+
+@patch('plinth.modules.apache.privileged.link_root')
+def test_webserver_root_enable(link_root):
+    """Test that enabling webserver root works."""
+    webserver = WebserverRoot('test-webserver', 'test-config')
+
+    with patch('plinth.modules.apache.components.WebserverRoot.domain_get'
+               ) as get:
+        get.return_value = None
+        webserver.enable()
+        link_root.assert_not_called()
+
+        get.return_value = 'x-domain'
+        webserver.enable()
+        link_root.assert_has_calls([call('x-domain', 'test-config')])
+
+
+@patch('plinth.modules.apache.privileged.unlink_root')
+def test_webserver_root_disable(unlink_root):
+    """Test that disabling webserver root works."""
+    webserver = WebserverRoot('test-webserver', 'test-config')
+
+    with patch('plinth.modules.apache.components.WebserverRoot.domain_get'
+               ) as get:
+        get.return_value = None
+        webserver.disable()
+        unlink_root.assert_not_called()
+
+        get.return_value = 'x-domain'
+        webserver.disable()
+        unlink_root.assert_has_calls([call('x-domain')])
+
+
+@pytest.mark.django_db
+def test_webserver_root_domain_get():
+    """Test retrieving webserver root's domain."""
+    webserver = WebserverRoot('test-webserver', 'test-config')
+
+    assert webserver.domain_get() is None
+    kvstore.set('test-webserver_domain', 'test-domain')
+    assert webserver.domain_get() == 'test-domain'
+
+
+@pytest.mark.django_db
+@patch('plinth.modules.apache.privileged.unlink_root')
+@patch('plinth.modules.apache.privileged.link_root')
+@patch('plinth.app.Component.app', new_callable=PropertyMock)
+def test_webserver_root_domain_set(component_app, link_root, unlink_root):
+    """Test setting webserver root's domain."""
+    webserver = WebserverRoot('test-webserver', 'test-config')
+    assert webserver.domain_get() is None
+
+    app = Mock()
+    component_app.return_value = app
+    app.is_enabled.return_value = True
+    webserver.domain_set('test-domain')
+    assert unlink_root.mock_calls == []
+    assert webserver.domain_get() == 'test-domain'
+    assert link_root.mock_calls == [call('test-domain', 'test-config')]
+    link_root.reset_mock()
+
+    app.is_enabled.return_value = False
+    assert not webserver.app.is_enabled()
+    webserver.domain_set('test-domain2')
+    assert unlink_root.mock_calls == [call('test-domain')]
+    assert webserver.domain_get() == 'test-domain2'
+    assert link_root.mock_calls == []
+
+    webserver.domain_set(None)
+    assert webserver.domain_get() is None
+
+
+@pytest.mark.django_db
+@patch('plinth.modules.apache.components.WebserverRoot.disable')
+@patch('plinth.modules.apache.components.WebserverRoot.enable')
+@patch('plinth.modules.apache.components.diagnose_url')
+@patch('plinth.app.Component.app', new_callable=PropertyMock)
+def test_webserver_root_diagnose(component_app, diagnose_url, enable, disable):
+    """Test running diagnostics on webserver root component."""
+    webserver = WebserverRoot('test-webserver', 'test-config')
+    assert webserver.diagnose() == []
+
+    webserver.domain_set('test-domain')
+    result = DiagnosticCheck('test-all-id', 'test-result', 'success', {},
+                             'message')
+    diagnose_url.return_value = result
+    assert webserver.diagnose() == [result]
+
+
+@patch('plinth.privileged.service.reload')
+def test_webserver_root_setup(service_reload):
+    """Test that component reloads web server during app upgrades."""
+
+    class AppTest(app.App):
+        app_id = 'testapp'
+        enabled = False
+
+        def is_enabled(self):
+            return self.enabled
+
+    app1 = AppTest()
+
+    # Don't fail when last_updated_version is not provided.
+    webserver1 = WebserverRoot('test-webserverroot1', 'test-config')
+    assert webserver1.last_updated_version == 0
+    webserver1.setup(old_version=10)
+    service_reload.assert_not_called()
+
+    webserver1 = WebserverRoot('test-webserverroot1', 'test-config',
+                               last_updated_version=5)
+    for version in (0, 5, 6):
+        webserver1.setup(old_version=version)
+        service_reload.assert_not_called()
+
+    app1.enabled = False
+    webserver2 = WebserverRoot('test-webserver2', 'test-config',
+                               last_updated_version=5)
+    app1.add(webserver2)
+    webserver2.setup(old_version=3)
+    service_reload.assert_not_called()
+
+    app1.enabled = True
+    webserver3 = WebserverRoot('test-webserver3', 'test-config',
+                               last_updated_version=5)
+    app1.add(webserver3)
+    webserver3.setup(old_version=3)
+    service_reload.assert_has_calls([call('apache2')])
+    service_reload.reset_mock()
+
+
+@pytest.mark.django_db
+@patch('plinth.modules.apache.components.WebserverRoot.disable')
+@patch('plinth.modules.apache.components.WebserverRoot.enable')
+@patch('plinth.app.Component.app', new_callable=PropertyMock)
+def test_webserver_root_uninstall(component_app, enable, disable):
+    """Test that component removes the DB key during uninstall."""
+    webserver = WebserverRoot('test-webserver', 'test-config')
+    webserver.uninstall()
+    assert kvstore.get_default('test-webserver_domain', 'x-value') == 'x-value'
+
+    webserver.domain_set('test-domain')
+    assert kvstore.get('test-webserver_domain') == 'test-domain'
+    webserver.uninstall()
+    assert kvstore.get_default('test-webserver_domain', 'x-value') == 'x-value'
+
+
 def test_uwsgi_init():
     """Test that uWSGI component can be initialized."""
     with pytest.raises(ValueError):
@@ -244,20 +416,23 @@ def test_diagnose_url(get_addresses, check):
             'test-1': 'value-1'
         },
         'wrapper': 'test-wrapper',
-        'expected_output': 'test-expected'
+        'expected_output': 'test-expected',
+        'component_id': 'test-component',
     }
     parameters = {key: args[key] for key in ['url', 'kind']}
     check.return_value = True
     result = diagnose_url(**args)
     assert result == DiagnosticCheck(
         'apache-url-kind-https://localhost/test-4',
-        'Access URL {url} on tcp{kind}', Result.PASSED, parameters)
+        'Access URL {url} on tcp{kind}', Result.PASSED, parameters,
+        'test-component')
 
     check.return_value = False
     result = diagnose_url(**args)
     assert result == DiagnosticCheck(
         'apache-url-kind-https://localhost/test-4',
-        'Access URL {url} on tcp{kind}', Result.FAILED, parameters)
+        'Access URL {url} on tcp{kind}', Result.FAILED, parameters,
+        'test-component')
 
     del args['kind']
     args['url'] = 'https://{host}/test'
@@ -287,10 +462,10 @@ def test_diagnose_url(get_addresses, check):
     assert results == [
         DiagnosticCheck('apache-url-kind-https://test-host-1/test-4',
                         'Access URL {url} on tcp{kind}', Result.PASSED,
-                        parameters[0]),
+                        parameters[0], 'test-component'),
         DiagnosticCheck('apache-url-kind-https://test-host-2/test-6',
                         'Access URL {url} on tcp{kind}', Result.PASSED,
-                        parameters[1]),
+                        parameters[1], 'test-component'),
     ]
 
 
