@@ -3,7 +3,12 @@
 Application manifest for ssh.
 """
 
+from django.utils.translation import gettext_lazy as _
+
 backup = {
+    'config': {
+        'files': ['/etc/ssh/sshd_config.d/freedombox.conf']
+    },
     'secrets': {
         'files': [
             '/etc/ssh/ssh_host_ecdsa_key', '/etc/ssh/ssh_host_ecdsa_key.pub',
@@ -13,3 +18,5 @@ backup = {
         ]
     }
 }
+
+tags = [_('SSH'), _('Remote terminal'), _('Fingerprints')]
