@@ -11,7 +11,6 @@ _TOR_FEATURE_TO_ELEMENT = {
     'relay': 'tor-relay_enabled',
     'bridge-relay': 'tor-bridge_relay_enabled',
     'hidden-services': 'tor-hs_enabled',
-    'software': 'tor-apt_transport_tor_enabled'
 }
 
 pytestmark = [pytest.mark.apps, pytest.mark.domain, pytest.mark.tor]
@@ -21,9 +20,6 @@ class TestTorApp(functional.BaseAppTests):
     app_name = 'tor'
     has_service = True
     has_web = False
-    # TODO: Investigate why accessing IPv6 sites through Tor fails in
-    # container.
-    check_diagnostics = False
 
     def test_set_tor_relay_configuration(self, session_browser):
         """Test setting Tor relay configuration."""
@@ -31,7 +27,7 @@ class TestTorApp(functional.BaseAppTests):
         _feature_enable(session_browser, 'relay', should_enable=False)
         _feature_enable(session_browser, 'relay', should_enable=True)
         _assert_feature_enabled(session_browser, 'relay', enabled=True)
-        assert 'orport' in _get_relay_ports(session_browser)
+        _assert_relay_port(session_browser, 'orport')
 
     def test_set_tor_bridge_relay_configuration(self, session_browser):
         """Test setting Tor bridge relay configuration."""
@@ -39,8 +35,8 @@ class TestTorApp(functional.BaseAppTests):
         _feature_enable(session_browser, 'bridge-relay', should_enable=False)
         _feature_enable(session_browser, 'bridge-relay', should_enable=True)
         _assert_feature_enabled(session_browser, 'bridge-relay', enabled=True)
-        assert 'obfs3' in _get_relay_ports(session_browser)
-        assert 'obfs4' in _get_relay_ports(session_browser)
+        _assert_relay_port(session_browser, 'obfs3')
+        _assert_relay_port(session_browser, 'obfs4')
 
     def test_set_tor_hidden_services_configuration(self, session_browser):
         """Test setting Tor hidden services configuration."""
@@ -52,13 +48,6 @@ class TestTorApp(functional.BaseAppTests):
                                 enabled=True)
         _assert_hidden_services(session_browser)
 
-    def test_set_download_software_packages_over_tor(self, session_browser):
-        """Test setting download software packages over Tor."""
-        functional.app_enable(session_browser, 'tor')
-        _feature_enable(session_browser, 'software', should_enable=True)
-        _feature_enable(session_browser, 'software', should_enable=False)
-        _assert_feature_enabled(session_browser, 'software', enabled=False)
-
     # TODO: Test more thoroughly by checking same hidden service is restored
     # and by actually connecting using Tor.
     @pytest.mark.backups
@@ -109,12 +98,12 @@ def _assert_feature_enabled(browser, feature, enabled):
     assert browser.find_by_name(element_name).first.checked == enabled
 
 
-def _get_relay_ports(browser):
-    """Return the list of ports shown in the relay table."""
+def _assert_relay_port(browser, port_name):
+    """Assert that port is available in port forwarding info table."""
     functional.nav_to_module(browser, 'tor')
-    return [
-        port_name.text
-        for port_name in browser.find_by_css('.tor-relay-port-name')
+    assert f'tor-{port_name}' in [
+        name.text for name in browser.find_by_css(
+            '.table-port-forwarding-info td:first-child')
     ]
 
 
