@@ -7,15 +7,16 @@ from .container import (container_disable, container_enable,
                         container_uninstall)
 from .packages import (filter_conffile_packages, install,
                        is_package_manager_busy, remove, update)
-from .service import (disable, enable, is_enabled, is_running, mask, reload,
-                      restart, start, stop, systemd_set_default,
+from .service import (disable, enable, get_logs, is_enabled, is_running, mask,
+                      reload, restart, start, stop, systemd_set_default,
                       try_reload_or_restart, try_restart, unmask)
 
 __all__ = [
     'filter_conffile_packages', 'install', 'is_package_manager_busy', 'remove',
     'update', 'systemd_set_default', 'disable', 'enable', 'is_enabled',
     'is_running', 'mask', 'reload', 'restart', 'start', 'stop',
-    'try_reload_or_restart', 'try_restart', 'unmask', 'dropin_is_valid',
-    'dropin_link', 'dropin_unlink', 'container_disable', 'container_enable',
-    'container_is_enabled', 'container_setup', 'container_uninstall'
+    'try_reload_or_restart', 'try_restart', 'unmask', 'get_logs',
+    'dropin_is_valid', 'dropin_link', 'dropin_unlink', 'container_disable',
+    'container_enable', 'container_is_enabled', 'container_setup',
+    'container_uninstall'
 ]
